
#include "config.h"

#include <stdio.h>
#include "../lib/libcpe.h"

#define REPORT_STR(e) printf("  %-15s = %s\n", #e, e)

const char* CPE_PART_STR[] = { "??? ERROR - run away!", "hardware", "operating system", "application" };

int main(int argc, char** argv)
{
	int i;

	if (argc < 2) {
		fprintf(stderr, "Usage: %s CPE_URI\n", argv[0]);
		fprintf(stderr, "CPE_URI example: 'cpe:/o:redhat:enterprise_linux:4:ga'\n");
	}

	if (argc > 2) {
		Cpe_t* cpes[5] = { NULL };
		Cpe_t* cpe = cpe_new(argv[1]);
		printf("Matching:\n  %s\nAgainst:\n", argv[1]);
		for (i = 0; i < 4 && i + 2 < argc; ++i) {
			cpes[i] = cpe_new(argv[i + 2]);
			printf("  %s\n", argv[i + 2]);
		}
		bool result = cpe_name_match(cpe, ptrarray_length((void**)cpes), cpes);
		printf ("%s\n\n", (result ? "MATCHED" : "UNMATCHED"));
		cpe_delete(cpe);
		for (i = 0; i < 4; ++i)
			free(cpes[i]);
	}

	for (i = 1; i < argc; ++i) {
		Cpe_t* cpe = cpe_new(argv[i]);
		printf("%s\n", argv[i]);
		if (cpe == NULL) {
			printf("  INVALID\n");
			continue;
		}
		printf("  %-15s = %s\n", "cpe->part", CPE_PART_STR[cpe->part]);
		REPORT_STR(cpe->vendor);
		REPORT_STR(cpe->product);
		REPORT_STR(cpe->version);
		REPORT_STR(cpe->update);
		REPORT_STR(cpe->edition);
		REPORT_STR(cpe->language);
		printf("\n");
		cpe_delete(cpe);
	}

	return 0;
}

